@@ -144,7 +144,7 @@ class ConfUtil:
     def _init(cls, conf):
         if cls.CONN is None:
             cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
+        elif cls.CFID != UniUtil.uuids(conf):
             cls.connect(conf)
 
     @classmethod
@@ -152,7 +152,7 @@ class ConfUtil:
         try:
             cls.CONN = configparser.ConfigParser()
             cls.CONN.read(conf, encoding='utf-8')
-            cls.CFID = UniUtil.get_uuid(conf)
+            cls.CFID = UniUtil.uuids(conf)
         except Exception as e:
             print("conf init failed, please check the config", e)
 
